@@ -20,12 +20,14 @@ package
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.08320_02';
+our $VERSION = '0.09026_01';
 
-require 5.006;
+$VERSION =~ /([0-9]{2})$/;
+my $compat_version = $1;
 
 use strict;
 use warnings;
+use 5.006;
 use Config;
 use File::Spec;
 use File::Glob 'bsd_glob';
@@ -69,10 +71,43 @@ our @DEFAULT_SEARCH_PATH = qw(
 
 );
 
+our @DEFAULT_EXCLUDE_CFLAGS = qw(-I/usr/include -I/usr/local/include);
+# don't include default link/search paths!
+our @DEFAULT_EXCLUDE_LFLAGS = map { ( "-L$_", "-R$_" ) } qw( /lib /lib32 /lib64 /usr/lib /usr/lib32 /usr/lib/64 /usr/local/lib /usr/local/lib32 /usr/local/lib64 );
+
 if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
 
     # use the defaults regardless of detected platform
 
+} elsif($ENV{PKG_CONFIG_LIBDIR}) {
+
+    @DEFAULT_SEARCH_PATH = split $Config{path_sep}, $ENV{PKG_CONFIG_LIBDIR};
+
+} elsif($^O eq 'solaris' && $Config{ptrsize} == 8) {
+
+    @DEFAULT_SEARCH_PATH = qw(
+        /usr/local/lib/64/pkgconfig /usr/local/share/pkgconfig
+        /usr/lib/64/pkgconfig /usr/share/pkgconfig
+    );
+
+} elsif($^O eq 'linux' and -f '/etc/gentoo-release') {
+    # OK, we're running on Gentoo
+
+    # Fetch ptrsize value
+    my $ptrsize = $Config{ptrsize};
+
+    # Are we running on 64 bit system?
+    if ($ptrsize eq 8) {
+        # We do
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib64/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    } else {
+        # We're running on a 32 bit system (hopefully)
+        @DEFAULT_SEARCH_PATH = qw!
+          /usr/lib/pkgconfig/ /usr/share/pkgconfig/
+        !;
+    }
 } elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
 
     my $arch;
@@ -115,6 +150,11 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
                 "/usr/lib/pkgconfig",
                 "/usr/share/pkgconfig",
             );
+
+            push @DEFAULT_EXCLUDE_LFLAGS, map { ("-L$_", "-R$_") } 
+                "/usr/local/lib/$arch",
+                "/usr/lib/$arch";
+
         } else {
         
             @DEFAULT_SEARCH_PATH = (
@@ -126,7 +166,7 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
                 "/usr/share/pkgconfig",
             );
         }
-    
+        
     } else {
 
         @DEFAULT_SEARCH_PATH = (
@@ -207,28 +247,36 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
         $path =~ s{\\}{/}g;
         @DEFAULT_SEARCH_PATH = $path;
     }
-
-}
-
-my @ENV_SEARCH_PATH = split($Config{path_sep}, $ENV{PKG_CONFIG_PATH} || "");
-
-unshift @DEFAULT_SEARCH_PATH, @ENV_SEARCH_PATH;
-
-our @DEFAULT_EXCLUDE_CFLAGS = qw(-I/usr/include -I/usr/local/include);
-# don't include default link/search paths!
-our @DEFAULT_EXCLUDE_LFLAGS = qw(
-    -L/usr/lib -L/lib -L/lib64 -L/lib32
-    -L/usr/lib32 -L/usr/lib64
-    -L/usr/local/lib
     
-    -R/lib -R/usr/lib -R/usr/lib64 -R/lib32 -R/lib64 -R/usr/local/lib
-);
-
-if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
-
-    # use the defaults regardless of detected platform
-
-} elsif($^O eq 'MSWin32') {
+    my @reg_paths;
+    
+    eval q{
+        package
+            PkgConfig::WinReg;
+        
+        use Win32API::Registry 0.21 qw( :ALL );
+        
+        foreach my $top (HKEY_LOCAL_MACHINE, HKEY_CURRENT_USER) {
+            my $key;
+            RegOpenKeyEx( $top, "Software\\\\pkgconfig\\\\PKG_CONFIG_PATH", 0, KEY_READ, $key) || next;
+            my $nlen = 1024;
+            my $pos = 0;
+            my $name = '';
+            
+            while(RegEnumValue($key, $pos++, $name, $nlen, [], [], [], [])) {
+                my $type;
+                my $data;
+                RegQueryValueEx($key, $name, [], $type, $data, []);
+                push @reg_paths, $data;
+            }
+            
+            RegCloseKey( $key );
+        }
+    };
+    
+    unless($@) {
+        unshift @DEFAULT_SEARCH_PATH, @reg_paths;
+    }
 
     if($Config::Config{cc} =~ /cl(\.exe)?$/i)
     {
@@ -271,6 +319,21 @@ if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
     }
 }
 
+my @ENV_SEARCH_PATH = split($Config{path_sep}, $ENV{PKG_CONFIG_PATH} || "");
+
+unshift @DEFAULT_SEARCH_PATH, @ENV_SEARCH_PATH;
+
+if($^O eq 'MSWin32') {
+  @DEFAULT_SEARCH_PATH = map { s{\\}{/}g; $_ } map { /\s/ ? Win32::GetShortPathName($_) : $_ } @DEFAULT_SEARCH_PATH;
+}
+
+if($ENV{PKG_CONFIG_ALLOW_SYSTEM_CFLAGS}) {
+    @DEFAULT_EXCLUDE_CFLAGS = ();
+}
+
+if($ENV{PKG_CONFIG_ALLOW_SYSTEM_LIBS}) {
+    @DEFAULT_EXCLUDE_LFLAGS = ();
+}
 
 my $LD_OUTPUT_RE = qr/
     SEARCH_DIR\("
@@ -392,12 +455,12 @@ struct(
 
 sub _get_pc_varname {
     my ($self,$vname_base) = @_;
-    return $self->varclass . "::" . $vname_base;
+    $self->varclass . "::" . $vname_base;
 }
 
 sub _get_pc_udefname {
     my ($self,$vname_base) = @_;
-    return $self->udefclass . "::" . $vname_base;
+    $self->udefclass . "::" . $vname_base;
 }
 
 sub _pc_var {
@@ -406,9 +469,7 @@ sub _pc_var {
     no strict 'refs';
     $vname = $self->_get_pc_varname($vname);
     my $glob = *{$vname};
-    return unless $glob;
-    
-    return $$glob;
+    $glob ? $$glob : ();
 }
 
 sub _quote_cvt($)  {
@@ -532,7 +593,7 @@ sub find {
         }
     }
     
-    return $o;
+    $o;
 }
 
 ################################################################################
@@ -613,7 +674,7 @@ sub get_requires {
         }
     }
     #log_debug(@ret);
-    return @ret;
+    @ret;
 }
 
 
@@ -838,7 +899,7 @@ sub get_list {
             }
         }
     }
-    return @rv;
+    @rv;
 }
 
 
@@ -861,7 +922,7 @@ sub _split_flags {
         @flags = shellwords $str;
     }
     @flags = grep $_, @flags;
-    return @flags;
+    @flags;
 }
 
 
@@ -906,7 +967,7 @@ sub version_2_array {
         && $chunk =~ /^\d+$/) {
         push @ret, $chunk;
     }
-    return @ret;
+    @ret;
 }
 
 
@@ -924,7 +985,7 @@ sub version_check {
             return 0;
         }
     }
-    return 1;
+    1;
 }
 
 
@@ -994,17 +1055,22 @@ GetOptions(
     'libs' => \my $PrintLibs,
     'libs-only-L' => \my $PrintLibsOnlyL,
     'libs-only-l' => \my $PrintLibsOnlyl,
+    'libs-only-other' => \my $PrintLibsOnlyOther,
     'list-all' => \my $ListAll,
     'static' => \my $UseStatic,
     'cflags' => \my $PrintCflags,
     'cflags-only-I' => \my $PrintCflagsOnlyI,
+    'cflags-only-other' => \my $PrintCflagsOnlyOther,
     'exists' => \my $PrintExists,
     'atleast-version=s' => \my $AtLeastVersion,
+    'atleast-pkgconfig-version=s' => \my $AtLeastPkgConfigVersion,
     'exact-version=s'   => \my $ExactVersion,
     'max-version=s'     => \my $MaxVersion,
 
     'silence-errors' => \my $SilenceErrors,
     'print-errors' => \my $PrintErrors,
+    'errors-to-stdout' => \my $ErrToStdOut,
+    'short-errors'     => \my $ShortErrors,
     
     'define-variable=s', => \my %UserVariables,
     
@@ -1041,10 +1107,18 @@ if($GuessPaths) {
 }
 
 if($PrintAPIversion) {
-    print "0.20\n";
+    print '0.', $compat_version, "\n";
     exit(0);
 }
 
+if($AtLeastPkgConfigVersion) {
+    my($major,$minor,$patch) = split /\./, $AtLeastPkgConfigVersion;
+    exit 1 if $major > 0;
+    exit 1 if $minor > $compat_version;
+    exit 1 if $minor == $compat_version && $patch > 0;
+    exit 0;
+}
+
 if($PrintRealVersion) {
 
     printf STDOUT ("ppkg-config - cruftless pkg-config\n" .
@@ -1055,11 +1129,21 @@ if($PrintRealVersion) {
 if($PrintErrors) {
     $quiet_errors = 0;
 }
+
 if($SilenceErrors) {
     $quiet_errors = 1;
 }
 
-my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintLibsOnlyl || $PrintVersion);
+# This option takes precedence over all other options
+# be it:
+# --silence-errors
+# or
+# --print-errors
+if ($ErrToStdOut) {
+ $quiet_errors = 2;
+}
+
+my $WantFlags = ($PrintCflags || $PrintLibs || $PrintLibsOnlyL || $PrintCflagsOnlyI || $PrintCflagsOnlyOther || $PrintLibsOnlyOther || $PrintLibsOnlyl || $PrintVersion);
 
 if($WantFlags) {
     $quiet_errors = 0 unless $SilenceErrors;
@@ -1110,7 +1194,14 @@ if($AtLeastVersion) {
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
-    print STDERR $o->errmsg unless $quiet_errors;
+    # --errors-to-stdout
+    if ($quiet_errors eq 2) {
+        print STDOUT $o->errmsg;
+    # --print-errors
+    } elsif ($quiet_errors eq 1) {
+        print STDERR $o->errmsg;
+    }
+    # --silence-errors
     exit(1);
 }
 
@@ -1149,10 +1240,18 @@ if($PrintCflagsOnlyI) {
     @print_flags = grep /^-I/, $o->get_cflags;
 }
 
+if($PrintCflagsOnlyOther) {
+    @print_flags = grep /^-[^I]/, $o->get_cflags;
+}
+
 if($PrintLibs) {
     @print_flags = $o->get_ldflags;
 }
 
+if ($PrintLibsOnlyOther) {
+    @print_flags = grep /^-[^LRl]/, $o->get_ldflags;
+}
+
 # handle --libs-only-L and --libs-only-l but watch the case when
 # we got 'ppkg-config --libs-only-L --libs-only-l foo' which must behave just like
 # 'ppkg-config --libs-only-l foo'
@@ -1250,6 +1349,11 @@ Prints -L/-R part of "--libs". It defines library search path but without librar
 
 Prints the -l part of "--libs".
 
+=head4 --libs-only-other
+
+Prints the part of "--libs" not covered by "--libs-only-L"
+and "--libs-only-l", such as "--pthread".
+
 =head4 --list-all
 
 List all know packages.
@@ -1262,6 +1366,10 @@ List all know packages.
 
 Prints the -I part of "--cflags"
 
+=head4 --cflags-only-other
+
+Prints the parts of "--cflags" not covered by "--cflags-only-I".
+
 =head4 --modversion
 
 Print the version of a given package.
@@ -1324,15 +1432,51 @@ arguments
 
 =head4 --print-errors
 
-This makes all errors noisy and takes precedence over
+Print errors to STDERR and takes precedence over
 C<--silence-errors>
 
+=head4 --short-errors
 
+Ignored, but recognized for compatability.
+
+=head4 --errors-to-stdout
+
+Print errors to STDOUT and takes precedence over
+C<--print-errors>
 
 =head3 ENVIRONMENT
 
-the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited 
-(semicolon-delimited on Windows) list of directories with contain C<.pc> files.
+the C<PKG_CONFIG_PATH> and C<PKG_CONFIG_LIBDIR> variables are honored and used
+as a colon-delimited (semicolon-delimited on Windows) list of directories with
+contain C<.pc> files.
+
+Other environment variables recongized by both C<pkg-config> and L<PkgConfig>
+include:
+
+=over 4
+
+=item PKG_CONFIG_ALLOW_SYSTEM_CFLAGS
+
+=item PKG_CONFIG_ALLOW_SYSTEM_LIBS
+
+=back
+
+If L<Win32API::Registry> is installed, on Windows (but not Cygwin) L<PkgConfig>
+will also consult these registry keys.  The names are ignored, but the values
+are paths containing C<.pc> files.
+
+=over 4
+
+=item HKEY_CURRENT_USER\Software\pkgconfig\PKG_CONFIG_PATH
+
+=item HKEY_LOCAL_MACHINE\Software\pkgconfig\PKG_CONFIG_PATH
+
+=back
+
+Registry support should be considered somewhat experimental, subject to change
+in the future, though not without good reason.  The rationale for this caveat
+is that this feature is documented in several places, but I have yet to find
+a working version that implements this feature.
 
 =head2 MODULE OPTIONS
 
@@ -1563,6 +1707,8 @@ Other contributors include:
 
 =item Sanel Zukan
 
+=item Breno G. de Oliveira (garu)
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
